@@ -423,122 +423,5 @@ score <- function(object,parm="delta"){
   }
 }
 
-#' Functions for internal use
-#'
-#' @param ... arguments passed to internal functions
-#' @name internal_GDINA
-NULL
-
-
-#' @name internal_Lik
-#' @export
-#' @rdname internal_GDINA
-internal_Lik <- function(...){
-args <- list(...)
-stopifnot(length(args)>0)
-if(is.null(args$group)) args$group <- rep(1,nrow(args$dat))
-if(is.null(args$weights)) args$weights <- rep(1,nrow(args$dat))
-if(is.null(args$simplify)) args$simplify <- 0
-LikNR(args$catprob.parm,
-      args$dat,
-      args$logprior,
-      args$group,
-      args$eta,
-      args$weights,
-      args$simplify)
-}
-#' @name internal_Lik2
-#' @export
-#' @rdname internal_GDINA
-internal_Lik2 <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  if(is.null(args$group)) args$group <- rep(1,nrow(args$dat))
-  if(is.null(args$weights)) args$weights <- rep(1,nrow(args$dat))
-  if(is.null(args$simplify)) args$simplify <- 0
-  LikNR_LC(args$LCprob,
-        args$dat,
-        args$logprior,
-        args$group,
-        args$weights,
-        args$simplify)
-}
-#' @name internal_aggregateCol
-#' @export
-#' @rdname internal_GDINA
-internal_aggregateCol <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  aggregateCol(args$x,
-               args$by)
-}
-
-#' @name internal_eta
-#' @export
-#' @rdname internal_GDINA
-internal_eta <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  eta(args$Q)
-}
-
-#' @name internal_matchMatrix
-#' @export
-#' @rdname internal_GDINA
-internal_matchMatrix <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  matchMatrix(args$A,args$B)
-}
-
-#' @name internal_RowNormalize
-#' @export
-#' @rdname internal_GDINA
-internal_RowNormalize <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  RowNormalize(args$x)
-}
-
-#' @name internal_ColNormalize
-#' @export
-#' @rdname internal_GDINA
-internal_ColNormalize <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  ColNormalize(args$x)
-}
-
-#' @name internal_RowProd
-#' @export
-#' @rdname internal_GDINA
-internal_RowProd <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  rowProd(args$x,args$v)
-}
-
-#' @name internal_l2m
-#' @export
-#' @rdname internal_GDINA
-internal_l2m <- function(...){
-  l2m(...)
-}
-
-#' @name internal_l2m
-#' @export
-#' @rdname internal_GDINA
-internal_m2l <- function(...){
-  m2l(...)
-}
-
-#' @name internal_uP
-#' @export
-#' @rdname internal_GDINA
-internal_uP <- function(...){
-  args <- list(...)
-  stopifnot(length(args)>0)
-  uP(args$eta, args$catprob.parm)
-}
 
 
