@@ -205,8 +205,8 @@
 #' @param latent.var A string indicating the nature of the latent variables. It is \code{"att"} (by default) if the latent variables are attributes,
 #'    and \code{"bugs"} if the latent variables are misconceptions. When \code{"bugs"} is specified, only the DINA, DINO or G-DINA model can be
 #'    specified in \code{model} argument (Kuo, Chen, Yang & Mok, 2016).
-#' @param att.str logical; are attributes structured? If yes, \code{att.prior} must be specified where impossible latent classes have prior weights 0.
-#'    If attributes are structured, only the DINA, DINO or G-DINA model can be specified in \code{model} argument.
+#' @param att.str Specify attribute structures. \code{NULL}, by default, means there is no structure. Attribute structure needs be specified as a list -
+#'    which will be internally handled by \code{att.structure} function. See examples. It can also be a matrix giving all permissible attribute profiles.
 #' @param loglinear the order of loglinear smooth for attribute space. It can be either 1 or 2 indicating the loglinear model with main effect only
 #'    and with main effect and first-order interaction.
 #' @param control A list of control parameters with elements:
@@ -249,6 +249,8 @@
 #' @seealso See \code{\link{autoGDINA}} for Q-matrix validation, item-level model comparison and model calibration
 #' in one run; See \code{\link{modelfit}} and \code{\link{itemfit}} for model and item fit analysis, \code{\link{Qval}} for Q-matrix validation,
 #' \code{\link{modelcomp}} for item level model comparison and \code{\link{simGDINA}} for data simulation.
+#' \code{\link{GMSCDM}} for a series of multiple strategy CDMs for dichotomous data,
+#' and \code{\link{DTM}} for diagnostic tree model for multiple strategies in polytomous response data
 #' Also see \code{gdina} in \pkg{CDM} package for the G-DINA model estimation.
 #'
 #' @return \code{GDINA} returns an object of class \code{GDINA}. Methods for \code{GDINA} objects
@@ -493,7 +495,7 @@
 #'####################################
 #'#          Example 4.              #
 #'#        Model estimations         #
-#'# With user-specified att structure#
+#'#    With fixed att structure      #
 #'####################################
 #'
 #' # --- User-specified attribute priors ----#
@@ -507,51 +509,12 @@
 #' dat <- sim10GDINA$simdat
 #' Q <- sim10GDINA$simQ
 #' modp1 <- GDINA(dat = dat, Q = Q, att.prior = prior, att.dist = "fixed")
-#' # See the posterior weights
-#' extract(modp1,what = "posterior.prob")
-#' extract(modp1,what = "att.prior")
-#' # ----Linear structure of attributes -----#
-#' # Assuming A1 -> A2 -> A3
-#'   Q <- matrix(c(1,0,0,
-#'                 1,0,0,
-#'                 1,1,0,
-#'                 1,1,0,
-#'                 1,1,1,
-#'                 1,1,1,
-#'                 1,0,0,
-#'                 1,0,0,
-#'                 1,1,0,
-#'                 1,1,0,
-#'                 1,1,1,
-#'                 1,1,1),ncol=3,byrow=TRUE)
-#'  # item parameters for DINA model (guessing and slip)
-#'  gs <- matrix(rep(0.1,24),ncol=2)
-#'  N <- 5000
-#'  # attribute simulation
-#'  att <- rbind(matrix(0,nrow=500,ncol=3),
-#'               matrix(rep(c(1,0,0),1000),ncol=3,byrow=TRUE),
-#'               matrix(rep(c(1,1,0),1000),ncol=3,byrow=TRUE),
-#'               matrix(rep(c(1,1,1),2500),ncol=3,byrow=TRUE))
-#'  # data simulation
-#'  simD <- simGDINA(N,Q,gs.parm = gs, model = "DINA",attribute = att)
-#'  dat <- simD$dat
-#'  # setting structure: A1 -> A2 -> A3
-#'  # note: latent classes with prior 0 are assumed impossible
-#'  prior <- c(0.1,0.2,0,0,0.2,0,0,0.5)
-#'  out <- GDINA(dat, Q, att.prior = prior,att.str = TRUE, att.dist = "fixed", model = "DINA")
-#'  # check posterior dist.
-#'  extract(out,what = "posterior.prob")
-#'  extract(out,what = "att.prior")
-#'
-#'  out2 <- GDINA(dat, Q, att.prior = prior,att.str = TRUE, att.dist = "saturated",model = "DINA")
-#'  # check posterior dist.
-#'  extract(out2,what = "posterior.prob")
-#'  extract(out2,what = "att.prior")
+#' extract(modp1, what = "att.prior")
 #'
 #'####################################
-#'#          Example 5.              #
-#'#        Model estimations         #
-#'# With user-specified att structure#
+#'#          Example 5a.             #
+#'#             G-DINA               #
+#'# with hierarchical att structure  #
 #'####################################
 #'
 #' # --- User-specified attribute structure ----#
@@ -563,7 +526,7 @@
 #'                c(1,4),
 #'                c(4,5))
 #'struc <- att.structure(diverg,K)
-#'
+#' set.seed(123)
 #' # data simulation
 #' N <- 1000
 #' true.lc <- sample(c(1:2^K),N,replace=TRUE,prob=struc$att.prob)
@@ -571,62 +534,78 @@
 #' true.att <- attributepattern(K)[true.lc,]
 #'  gs <- matrix(rep(0.1,2*nrow(Q)),ncol=2)
 #'  # data simulation
-#'  simD <- simGDINA(N,Q,gs.parm = gs, model = "DINA",attribute = true.att)
+#'  simD <- simGDINA(N,Q,gs.parm = gs, model = "GDINA",attribute = true.att)
 #'  dat <- extract(simD,"dat")
 #'
-#' modp1 <- GDINA(dat = dat, Q = Q, att.prior = struc$att.prob,
-#'                att.str = TRUE, att.dist = "saturated")
+#' modp1 <- GDINA(dat = dat, Q = Q, att.str = diverg, att.dist = "saturated")
 #' modp1
-#' # prior dist.
-#' extract(modp1,what = "att.prior")
-#' # Posterior weights were slightly different
-#' extract(modp1,what = "posterior.prob")
-#' modp2 <- GDINA(dat = dat, Q = Q, att.prior = struc$att.prob,
-#'                att.str = TRUE, att.dist = "fixed")
-#' modp2
-#' extract(modp2,what = "att.prior")
-#' extract(modp2,what = "posterior.prob")
+#' coef(modp1,"lambda")
 #'
+#'####################################
+#'#          Example 5b.             #
+#'#   Reduced model (e.g.,ACDM)      #
+#'# with hierarchical att structure  #
+#'####################################
+#'
+#' # --- User-specified attribute structure ----#
+#' Q <- sim30GDINA$simQ
+#' K <- ncol(Q)
+#' # linear structure A1->A2->A3->A4->A5
+#' linear <- list(c(1,2),
+#'                c(2,3),
+#'                c(3,4),
+#'                c(4,5))
+#'struc <- att.structure(linear,K)
+#' set.seed(123)
+#' # data simulation
+#' N <- 1000
+#' true.lc <- sample(c(1:2^K),N,replace=TRUE,prob=struc$att.prob)
+#' table(true.lc) #check the sample
+#' true.att <- attributepattern(K)[true.lc,]
+#'  gs <- matrix(rep(0.1,2*nrow(Q)),ncol=2)
+#'  # data simulation
+#'  simD <- simGDINA(N,Q,gs.parm = gs, model = "ACDM",attribute = true.att)
+#'  dat <- extract(simD,"dat")
+#'
+#' modp1 <- GDINA(dat = dat, Q = Q, model = "ACDM",
+#'                att.str = linear, att.dist = "saturated")
+#' coef(modp1)
+#' coef(modp1,"lambda")
 #'
 #'####################################
 #'#           Example 6.             #
-#'#        Model estimations         #
-#'# With user-specified initial pars #
+#'# Fix item and structure parameters#
+#'# Estimate person attribute profile#
 #'####################################
 #'
 #'  # check initials to see the format for initial item parameters
 #'  initials <- sim10GDINA$simItempar
+#'  prior <- c(0.1,0.1,0.1,0.1,0.15,0.15,0.15,0.15)
 #'  dat <- sim10GDINA$simdat
 #'  Q <- sim10GDINA$simQ
-#'  mod.ini <- GDINA(dat,Q,catprob.parm = initials)
-#'  extract(mod.ini,"initial.catprob")
+#'  mod.ini <- GDINA(dat,Q,catprob.parm = initials,att.prior = prior,
+#'                   att.dist = "fixed",control=list(maxitr = 0))
+#'  personparm(mod.ini)
+#'  # compare item parameters
+#'  Map(rbind, initials,coef(mod.ini))
 #'
 #'####################################
 #'#           Example 7.             #
-#'#        Model estimation          #
-#'#          Without M-step          #
+#'#   Fix parameters for some items  #
+#'# Estimate person attribute profile#
 #'####################################
 #'
-#'  # -----------Fix User-specified item parameters
-#'  # Item parameters are not estimated
-#'  # Only person attributes are estimated
-#'  # attribute prior distribution matters if interested in the marginalized likelihood
-#'  dat <- frac20$dat
-#'  Q <- frac20$Q
-#'  # estimation- only 20 iterations for illustration purposes
-#'  mod.initial <- GDINA(dat,Q,control = list(maxitr=20))
-#'  par <- coef(mod.initial,digits=8)
-#'  weights <- extract(mod.initial,"posterior.prob",digits=8) #posterior weights
-#'  # use the weights as the priors
-#'  mod.fix <- GDINA(dat,Q,catprob.parm = par,
-#'                   att.prior=c(weights),control = list(maxitr = 0)) # re-estimation
-#'  anova(mod.initial,mod.fix) # very similar - good approximation most of time
-#'  # prior used for the likelihood calculation for the last step
-#'  priors <- extract(mod.initial,"att.prior")
-#'  # use the priors as the priors
-#'  mod.fix2 <- GDINA(dat,Q,catprob.parm = par,
-#'                    att.prior=priors, control = list(maxitr=0)) # re-estimation
-#'  anova(mod.initial,mod.fix2) # identical results
+#'  # check initials to see the format for initial item parameters
+#'  initials <- sim10GDINA$simItempar
+#'  prior <- c(0.1,0.1,0.1,0.1,0.15,0.15,0.15,0.15)
+#'  dat <- sim10GDINA$simdat
+#'  Q <- sim10GDINA$simQ
+#'  # fix parameters of the first 5 items; do not fix mixing proportion parameters
+#'  mod.ini <- GDINA(dat,Q,catprob.parm = initials,
+#'                   att.dist = "saturated",control=list(maxitr = c(rep(0,5),rep(2000,5))))
+#'  personparm(mod.ini)
+#'  # compare item parameters
+#'  Map(rbind, initials,coef(mod.ini))
 #'
 #'####################################
 #'#           Example 8.             #
@@ -697,14 +676,11 @@
 #'                  higher.order.parm = list(theta = rnorm(N2),
 #'                  lambda = data.frame(a=rep(1,K),b=seq(-2,2,length.out=K))))
 #'
-#' # combine data
-#' # see ?bdiagMatrix
-#' dat <- bdiagMatrix(list(extract(sim1,"dat"),extract(sim2,"dat")),fill=NA)
-#' Q <- rbind(Q,Q)
+#' # combine data - all items have the same item parameters
+#' dat <- rbind(extract(sim1,"dat"),extract(sim2,"dat"))
 #' gr <- rep(c(1,2),c(3000,3000))
 #' # Fit G-DINA model
-#' mg.est <- GDINA(dat = dat,Q = Q,group = gr,att.dist="higher.order",
-#' higher.order=list(model = "1PL",Prior=TRUE))
+#' mg.est <- GDINA(dat = dat,Q = Q,group = gr)
 #' summary(mg.est)
 #' extract(mg.est,"posterior.prob")
 #' coef(mg.est,"lambda")
@@ -732,16 +708,20 @@
 #'                  higher.order.parm = list(theta = rnorm(N2,1,1),
 #'                  lambda = data.frame(a=rep(1,K),b=seq(-2,2,length.out=K))))
 #'
-#' # combine data
+#' # combine data - different groups have distinct item parameters
 #' # see ?bdiagMatrix
 #' dat <- bdiagMatrix(list(extract(sim1,"dat"),extract(sim2,"dat")),fill=NA)
 #' Q <- rbind(Q,Q)
 #' gr <- rep(c(1,2),c(3000,3000))
+#' mg.est <- GDINA(dat = dat,Q = Q,group = gr)
 #' # Fit G-DINA model
 #' mg.est <- GDINA(dat = dat,Q = Q,group = gr,att.dist="higher.order",
-#' higher.order=list(model = "Rasch",Prior=FALSE,Type = "SameLambda"))
+#' higher.order=list(model = "Rasch"))
 #' summary(mg.est)
 #' coef(mg.est,"lambda")
+#' personparm(mg.est)
+#' personparm(mg.est,"HO")
+#' extract(mg.est,"posterior.prob")
 #'
 #'
 #'####################################
@@ -762,7 +742,7 @@
 #' c(0.9,0.1,0.1,0.1),
 #' c(0.9,0.1,0.1,0.1),
 #' c(0.9,0.1,0.1,0.1,0.1,0.1,0.1,0.1))
-#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip)
+#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip,model = "DINO")
 #' dat <- extract(sim,"dat")
 #' # use latent.var to specify a bug model
 #' est <- GDINA(dat=dat,Q=Q,latent.var="bugs",model="DINO")
@@ -786,7 +766,7 @@
 #' c(0.9,0.9,0.9,0.1),
 #' c(0.9,0.9,0.9,0.1),
 #' c(0.9,0.9,0.9,0.9,0.9,0.9,0.9,0.1))
-#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip)
+#' sim <- simGDINA(N=1000,Q=Q,catprob.parm = ip,model="DINA")
 #' dat <- extract(sim,"dat")
 #' # use latent.var to specify a bug model
 #' est <- GDINA(dat=dat,Q=Q,latent.var="bugs",model="DINA")
@@ -815,7 +795,7 @@
 #' iGDINA <- GDINA(dat = dat, Q = Q, model = "GDINA",
 #' control=list(conv.type="neg2LL"),solver="slsqp")
 #'
-#' # compare two models => identical
+#' # compare all three models => identical
 #' anova(lcdm,lcdm2,iGDINA)
 #'
 #'####################################
@@ -878,7 +858,7 @@
 GDINA <-
   function(dat, Q, model = "GDINA", sequential = FALSE, att.dist = "saturated", mono.constraint = FALSE,
            group = NULL,linkfunc = NULL, design.matrix = NULL,
-           latent.var = "att", att.prior = NULL, att.str = FALSE, verbose = 1,
+           latent.var = "att", att.prior = NULL, att.str = NULL, verbose = 1,
            higher.order = list(),loglinear = 2,catprob.parm = NULL,control=list(),
            item.names = NULL, solver = NULL,
            nloptr.args=list(),auglag.args=list(),solnp.args = list(),...)
@@ -900,16 +880,27 @@ GDINA <-
     constr.pairs <- dots("constr.pairs",NULL,...)
 
 
-    ret <- Est(dat = dat, Q = Q, model = model, sequential = sequential,
-             att.dist = att.dist, att.prior = att.prior,saturated=saturated,
-             att.str = att.str, mono.constraint=mono.constraint,
-             group = group, latent.var=latent.var, verbose = verbose,
-             catprob.parm = catprob.parm,loglinear = loglinear,
-             item.names = item.names, control = control, item.prior = item.prior,
-             nloptr_args = nloptr.args,auglag_args=auglag.args,solnp_args = solnp.args,
-             linkfunc = linkfunc,higher.order = higher.order, solver = solver,
-             DesignMatrices = design.matrix,ConstrPairs = constr.pairs)
-
+    if(is.null(group)){
+      ret <- SG.Est(dat = dat, Q = Q, model = model, sequential = sequential,
+                    att.dist = att.dist, att.prior = att.prior,saturated=saturated,
+                    att.str = att.str, mono.constraint=mono.constraint,
+                    latent.var = latent.var, verbose = verbose,
+                    catprob.parm = catprob.parm,loglinear = loglinear,
+                    item.names = item.names, control = control, item.prior = item.prior,
+                    nloptr_args = nloptr.args,auglag_args=auglag.args,solnp_args = solnp.args,
+                    linkfunc = linkfunc,higher.order = higher.order, solver = solver,
+                    DesignMatrices = design.matrix, ConstrPairs = constr.pairs)
+    }else{
+      ret <- MG.Est(dat = dat, Q = Q, model = model, sequential = sequential,
+                    att.dist = att.dist, att.prior = att.prior,saturated=saturated,
+                    att.str = att.str, mono.constraint=mono.constraint,
+                    group = group, latent.var=latent.var, verbose = verbose,
+                    catprob.parm = catprob.parm,loglinear = loglinear,
+                    item.names = item.names, control = control, item.prior = item.prior,
+                    nloptr_args = nloptr.args,auglag_args=auglag.args,solnp_args = solnp.args,
+                    linkfunc = linkfunc,higher.order = higher.order, solver = solver,
+                    DesignMatrices = design.matrix,ConstrPairs = constr.pairs)
+    }
 
     s2 <- Sys.time()
 
